@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class AddIpControlPolicyItemRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'AddIpControlPolicyItem')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'AddIpControlPolicyItem','apigateway')
 
 	def get_IpControlId(self):
 		return self.get_query_params().get('IpControlId')
@@ -29,12 +29,6 @@ class AddIpControlPolicyItemRequest(RpcRequest):
 	def set_IpControlId(self,IpControlId):
 		self.add_query_param('IpControlId',IpControlId)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_AppId(self):
 		return self.get_query_params().get('AppId')
 
