@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class CreateAppRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'CreateApp')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'CreateApp','apigateway')
 
 	def get_AppName(self):
 		return self.get_query_params().get('AppName')
@@ -29,12 +29,6 @@ class CreateAppRequest(RpcRequest):
 	def set_AppName(self,AppName):
 		self.add_query_param('AppName',AppName)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_Description(self):
 		return self.get_query_params().get('Description')
 
