@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class CreateTrafficControlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'CreateTrafficControl')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'CreateTrafficControl','apigateway')
 
 	def get_ApiDefault(self):
 		return self.get_query_params().get('ApiDefault')
@@ -29,12 +29,6 @@ class CreateTrafficControlRequest(RpcRequest):
 	def set_ApiDefault(self,ApiDefault):
 		self.add_query_param('ApiDefault',ApiDefault)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_TrafficControlName(self):
 		return self.get_query_params().get('TrafficControlName')
 
