@@ -21,16 +21,10 @@ from aliyunsdkcore.request import RpcRequest
 class DeleteIpControlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DeleteIpControl')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DeleteIpControl','apigateway')
 
 	def get_IpControlId(self):
 		return self.get_query_params().get('IpControlId')
 
 	def set_IpControlId(self,IpControlId):
-		self.add_query_param('IpControlId',IpControlId)
-
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
+		self.add_query_param('IpControlId',IpControlId)
\ No newline at end of file
