@@ -21,16 +21,10 @@ from aliyunsdkcore.request import RpcRequest
 class DeleteLogConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DeleteLogConfig')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DeleteLogConfig','apigateway')
 
 	def get_LogType(self):
 		return self.get_query_params().get('LogType')
 
 	def set_LogType(self,LogType):
-		self.add_query_param('LogType',LogType)
-
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
+		self.add_query_param('LogType',LogType)
\ No newline at end of file
