@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeApiDocRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApiDoc')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApiDoc','apigateway')
 
 	def get_StageName(self):
 		return self.get_query_params().get('StageName')
@@ -29,12 +29,6 @@ class DescribeApiDocRequest(RpcRequest):
 	def set_StageName(self,StageName):
 		self.add_query_param('StageName',StageName)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_GroupId(self):
 		return self.get_query_params().get('GroupId')
 
