@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeApiHistoriesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApiHistories')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApiHistories','apigateway')
 
 	def get_StageName(self):
 		return self.get_query_params().get('StageName')
@@ -35,12 +35,6 @@ class DescribeApiHistoriesRequest(RpcRequest):
 	def set_ApiName(self,ApiName):
 		self.add_query_param('ApiName',ApiName)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_GroupId(self):
 		return self.get_query_params().get('GroupId')
 
