@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeApisByIpControlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApisByIpControl')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApisByIpControl','apigateway')
 
 	def get_IpControlId(self):
 		return self.get_query_params().get('IpControlId')
@@ -29,12 +29,6 @@ class DescribeApisByIpControlRequest(RpcRequest):
 	def set_IpControlId(self,IpControlId):
 		self.add_query_param('IpControlId',IpControlId)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
 
