@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeApisByTrafficControlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApisByTrafficControl')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApisByTrafficControl','apigateway')
 
 	def get_TrafficControlId(self):
 		return self.get_query_params().get('TrafficControlId')
@@ -29,12 +29,6 @@ class DescribeApisByTrafficControlRequest(RpcRequest):
 	def set_TrafficControlId(self,TrafficControlId):
 		self.add_query_param('TrafficControlId',TrafficControlId)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
 
