@@ -21,19 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeAppAttributesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeAppAttributes')
-
-	def get_AppName(self):
-		return self.get_query_params().get('AppName')
-
-	def set_AppName(self,AppName):
-		self.add_query_param('AppName',AppName)
-
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeAppAttributes','apigateway')
 
 	def get_AppId(self):
 		return self.get_query_params().get('AppId')
