@@ -21,16 +21,4 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeRegionsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeRegions')
-
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_Language(self):
-		return self.get_query_params().get('Language')
-
-	def set_Language(self,Language):
-		self.add_query_param('Language',Language)
\ No newline at end of file
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeRegions','apigateway')
\ No newline at end of file
