@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class ModifyLogConfigRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'ModifyLogConfig')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'ModifyLogConfig','apigateway')
 
 	def get_SlsLogStore(self):
 		return self.get_query_params().get('SlsLogStore')
@@ -35,12 +35,6 @@ class ModifyLogConfigRequest(RpcRequest):
 	def set_LogType(self,LogType):
 		self.add_query_param('LogType',LogType)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_SlsProject(self):
 		return self.get_query_params().get('SlsProject')
 
