@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class ModifyTrafficControlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'ModifyTrafficControl')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'ModifyTrafficControl','apigateway')
 
 	def get_TrafficControlId(self):
 		return self.get_query_params().get('TrafficControlId')
@@ -35,12 +35,6 @@ class ModifyTrafficControlRequest(RpcRequest):
 	def set_ApiDefault(self,ApiDefault):
 		self.add_query_param('ApiDefault',ApiDefault)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_TrafficControlName(self):
 		return self.get_query_params().get('TrafficControlName')
 
