@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class RemoveIpControlPolicyItemRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'RemoveIpControlPolicyItem')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'RemoveIpControlPolicyItem','apigateway')
 
 	def get_IpControlId(self):
 		return self.get_query_params().get('IpControlId')
@@ -29,12 +29,6 @@ class RemoveIpControlPolicyItemRequest(RpcRequest):
 	def set_IpControlId(self,IpControlId):
 		self.add_query_param('IpControlId',IpControlId)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_PolicyItemIds(self):
 		return self.get_query_params().get('PolicyItemIds')
 
