@@ -21,13 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class SetApisAuthoritiesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'SetApisAuthorities')
-
-	def get_AuthVaildTime(self):
-		return self.get_query_params().get('AuthVaildTime')
-
-	def set_AuthVaildTime(self,AuthVaildTime):
-		self.add_query_param('AuthVaildTime',AuthVaildTime)
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'SetApisAuthorities','apigateway')
 
 	def get_StageName(self):
 		return self.get_query_params().get('StageName')
@@ -35,12 +29,6 @@ class SetApisAuthoritiesRequest(RpcRequest):
 	def set_StageName(self,StageName):
 		self.add_query_param('StageName',StageName)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_GroupId(self):
 		return self.get_query_params().get('GroupId')
 
@@ -59,12 +47,6 @@ class SetApisAuthoritiesRequest(RpcRequest):
 	def set_Description(self,Description):
 		self.add_query_param('Description',Description)
 
-	def get_AuthValidTime(self):
-		return self.get_query_params().get('AuthValidTime')
-
-	def set_AuthValidTime(self,AuthValidTime):
-		self.add_query_param('AuthValidTime',AuthValidTime)
-
 	def get_ApiIds(self):
 		return self.get_query_params().get('ApiIds')
 
