@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class SetVpcAccessRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'SetVpcAccess')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'SetVpcAccess','apigateway')
 
 	def get_InstanceId(self):
 		return self.get_query_params().get('InstanceId')
@@ -29,12 +29,6 @@ class SetVpcAccessRequest(RpcRequest):
 	def set_InstanceId(self,InstanceId):
 		self.add_query_param('InstanceId',InstanceId)
 
-	def get_SecurityToken(self):
-		return self.get_query_params().get('SecurityToken')
-
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
 	def get_Port(self):
 		return self.get_query_params().get('Port')
 
